<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="14"/>
        <source>OpenSSH Authentication Passphrase request</source>
        <translation>Запит паролю розпізнавання OpenSSH</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="20"/>
        <source>Enter your SSH passphrase for request:</source>
        <translation>Введіть ваш пароль SSH для запиту:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="52"/>
        <source>unknown request</source>
        <translation>невідомий запит</translation>
    </message>
</context>
</TS>
